TestTransactionPoolExt

Struct TestTransactionPoolExt 

pub struct TestTransactionPoolExt(/* private fields */);
Implementation of transaction pool used for test.

Note that this implementation does not verify correctness of sent extrinsics. It’s meant to be used in contexts where an actual runtime is not known.

It’s advised to write integration tests that include the actual transaction pool to make sure the produced transactions are valid.

Implementations

Source

impl TestTransactionPoolExt

pub fn new() -> (TestTransactionPoolExt, Arc<RwLock<RawRwLock, PoolState>>)

Create new TestTransactionPoolExt and a reference to the internal state.