Struct RandomState
pub struct RandomState { /* private fields */ }Expand description
RandomState is the default state for HashMap types.
A particular instance RandomState will create the same instances of
Hasher, but the hashers created by two different RandomState
instances are unlikely to produce the same result for the same values.
Examples
use std::collections::HashMap;
use std::hash::RandomState;
let s = RandomState::new();
let mut map = HashMap::with_hasher(s);
map.insert(1, 2);Implementations
impl RandomState
impl RandomState
1.7.0pub fn new() -> RandomState
pub fn new() -> RandomState
Constructs a new RandomState that is initialized with random keys.
Examples
use std::hash::RandomState;
let s = RandomState::new();Trait Implementations
1.7.0impl BuildHasher for RandomState
impl BuildHasher for RandomState
type Hasher = DefaultHasher
type Hasher = DefaultHasher
Type of the hasher that will be created.
fn build_hasher(&self) -> DefaultHasher
fn build_hasher(&self) -> DefaultHasher
Creates a new hasher. Read more
1.7.0impl Clone for RandomState
impl Clone for RandomState
fn clone(&self) -> RandomState
fn clone(&self) -> RandomState
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more1.16.0impl Debug for RandomState
impl Debug for RandomState
1.7.0impl Default for RandomState
impl Default for RandomState
fn default() -> RandomState
fn default() -> RandomState
Constructs a new RandomState.