Skip to main content Crate yet_another_parachain_runtime Copy item path Source pub use polkadot_sdk::staging_parachain_info as parachain_info;api cumulus_pallet_aura_ext Cumulus extension pallet for AuRa cumulus_pallet_weight_reclaim Pallet and transaction extensions to reclaim PoV proof size weight after an extrinsic has been
applied. cumulus_pallet_xcm Pallet for stuff specific to parachains’ usage of XCM. Right now that’s just the origin
used by parachains when receiving Transact messages from other parachains or the Relay chain
which must be natively represented. cumulus_pallet_xcmp_queue A pallet which uses the XCMP transport layer to handle both incoming and outgoing XCM message
sending and dispatch, queuing, signalling and backpressure. To do so, it implements: cumulus_primitives_aura Core primitives for Aura in Cumulus. cumulus_primitives_core Cumulus related core primitive types and traits. cumulus_primitives_utility Helper datatypes for cumulus. This includes the ParentAsUmp routing type which will route
messages into an UpwardMessageSender if the destination is Parent. frame_benchmarking Macro for benchmarking a FRAME runtime. frame_benchmarking_pallet_pov End-to-end testing pallet for PoV benchmarking. Should only be deployed in a testing runtime. frame_election_provider_solution_type Proc macro for a npos solution type. frame_election_provider_support Primitive traits for providing election functionality. frame_executive Executive Module frame_metadata_hash_extension The CheckMetadataHash transaction extension. frame_support Support code for the runtime. frame_support_procedural Proc macro of Support code for the runtime. frame_support_procedural_tools_derive Use to derive parsing for parsing struct. frame_system System Pallet frame_system_benchmarking Frame System benchmarks. frame_system_rpc_runtime_api Runtime API definition required by System RPC extensions. frame_try_runtime Supporting types for try-runtime, testing and dry-running commands. pallet_aura Aura Module pallet_authorship Authorship tracking for FRAME runtimes. pallet_balances Balances Pallet pallet_collator_selection Collator Selection pallet. pallet_message_queue Generalized Message Queue Pallet pallet_session Session Pallet pallet_sudo
Made with Substrate , for Polkadot .
pallet_timestamp
Made with Substrate , for Polkadot .
pallet_transaction_payment Transaction Payment Pallet pallet_transaction_payment_rpc_runtime_api Runtime API definition for transaction payment pallet. pallet_utility Utility Pallet pallet_verify_signature Transaction extension which validates a signature against a payload constructed from a call and
the rest of the transaction extension pipeline. pallet_xcm Pallet to handle XCM messages. parachains_common polkadot_parachain_primitives Defines primitive types for creating or validating a parachain. polkadot_runtime_common Common runtime code for the Relay Chain, e.g. Rococo, Westend, Polkadot, Kusama … polkadot_sdk_frame FRAME sp_api_proc_macro Macros for declaring and implementing runtime apis. sp_authority_discovery Runtime Api to help discover authorities. sp_consensus_babe Primitives for BABE. sp_consensus_beefy Primitives for BEEFY protocol. sp_consensus_pow Primitives for Substrate Proof-of-Work (PoW) consensus. sp_consensus_slots Primitives for slots-based consensus engines. sp_crypto_ec_utils This crate offers elliptic curves types which are compatible with the
Arkworks library functionalities. sp_dap Primitives for the Dynamic Allocation Pool (DAP). sp_debug_derive Macros to derive runtime debug implementation. sp_externalities Substrate externalities abstraction sp_hop HOP (Hand-Off Protocol) primitives. sp_keystore Keystore traits sp_mixnet Substrate mixnet types and runtime interface. sp_mmr_primitives Merkle Mountain Range primitive types. sp_npos_elections A set of election algorithms to be used with a substrate runtime, typically within the staking
sub-system. Notable implementation include: sp_runtime_interface Substrate runtime interface sp_runtime_interface_proc_macro This crate provides procedural macros for usage within the context of the Substrate runtime
interface. sp_session Substrate core types around sessions. sp_staking A crate which contains primitives that are useful for implementation that uses staking
approaches in general. Definitions related to sessions, slashing, etc go here. sp_state_machine Substrate state machine implementation. sp_statement_store A crate which contains statement-store primitives. sp_timestamp Substrate core types and inherents for timestamps. sp_transaction_pool Transaction pool runtime facing API. sp_transaction_storage_proof Storage proof primitives. Contains types and basic code to extract storage
proofs for indexed transactions. sp_trie Utility functions to interact with Substrate’s Base-16 Modified Merkle Patricia tree (“trie”). sp_version_proc_macro A proc-macro that generates a custom wasm section from a given RuntimeVersion declaration sp_virtualization This crate is intended for use by runtime code (e.g pallet-contracts) to spawn PolkaVM instances
and execute calls into them. Its purpose is to add one layer of abstraction to that it works
transparently from the actual runtime (via the host functions defined in this crate) but also
from tests (which run natively). sp_weights Primitives for transaction weighting. staging_parachain_info Minimal Pallet that injects a ParachainId into Runtime storage from staging_xcm Cross-Consensus Message format data structures. staging_xcm_builder XCM-Builder staging_xcm_executor construct_runtime Construct a runtime, with the given name and the given pallets. parameter_types Create new implementations of the Get trait. AsEnsureOriginWithArg BlockExecutionWeight Weight of executing an empty block.
Calculated by multiplying the Average with 1.0 and adding 0. BlockHashCount BoundedSlice A bounded slice. ConstBool Const getter for a basic type. ConstU8 Const getter for a basic type. ConstU32 Const getter for a basic type. ConstU64 Const getter for a basic type. ConstantMultiplier Implementor of WeightToFee that uses a constant multiplier. DmpSink EitherOfDiverse “OR gate” implementation of EnsureOrigin allowing for different Success types for L
and R, with them combined using an Either type. ExistentialDeposit IdentityFee Implementor of WeightToFee that maps one unit of weight to one unit of fee. InMemoryDbWeight IsInVec Trivial utility for implementing Contains/OrderedMembership with a Vec. MessageQueueServiceWeight Offset PalletId A pallet identifier. These are per pallet and should be stored in a registry somewhere. PalletInfo Provides an implementation of PalletInfo to provide information
about the pallet setup in the runtime. Perbill A fixed point representation of a number in the range [0, 1]. Period Permill A fixed point representation of a number in the range [0, 1]. PotId QueueFootprint The resource footprint of a queue. RelayOrigin RemoveCollectiveFlip ReservedDmpWeight ReservedXcmpWeight Runtime RuntimeApi RuntimeApiImpl Implements all runtime apis for the client side. RuntimeBlockLength RuntimeBlockWeights RuntimeGenesisConfig RuntimeOrigin The runtime origin type representing the origin of a call. SS58Prefix SessionKeys Generated by impl_opaque_keys! . SessionLength StakingAdminBodyId TransactionByteFee TransformOrigin Transform the origin of an EnqueueMessage via C::convert. Version Weight WeightToFee WeightToFeeCoefficient One coefficient and its position in the WeightToFee. BalancesCall Contains a variant per dispatchable extrinsic that this pallet has. DispatchClass A generalized group of dispatch types. Everything A Contains implementation that contains every value. Nothing A Contains implementation that contains no value. OriginCaller RuntimeCall The aggregated runtime call type. RuntimeError RuntimeEvent RuntimeFreezeReason A reason for placing a freeze on funds. RuntimeHoldReason A reason for placing a hold on funds. RuntimeLockId An identifier for each lock placed on funds. RuntimeSlashReason A reason for slashing funds. RuntimeTask An aggregation of all Task enums across all pallets included in the current runtime. RuntimeViewFunction Runtime query type. TimestampCall Contains a variant per dispatchable extrinsic that this pallet has. DAYS EPOCH_DURATION_IN_BLOCKS HOURS MILLISECS_PER_BLOCK MINUTES NANOYAP RUNTIME_API_VERSIONS SLOT_DURATION VERSION This runtime version. WASM_BINARY WASM_BINARY_BLOATY WASM_BINARY_PATH WEIGHT_REF_TIME_PER_SECOND YAP BuildStorage Complex storage builder stuff. Contains A trait for querying whether a type can be said to “contain” a value. HandleMessage Handles incoming messages for a single origin. Randomness A trait that is able to provide randomness. StorageValue A trait for working with macro-generated storage values under the substrate storage API. WeightToFeePolynomial A trait that describes the weight to fee calculation as polynomial. build_state Build GenesisConfig from a JSON blob not using any defaults and store it in the storage. For
more info refer to sp_genesis_builder::GenesisBuilder::build_state . get_preset Get the default GenesisConfig as a JSON blob if name is None. native_version The version information used to identify this runtime when compiled natively. Address The address format for describing accounts. AllPalletsWithSystem All pallets included in the runtime as a nested tuple of types. AllPalletsWithoutSystem All pallets included in the runtime as a nested tuple of types.
Excludes the System pallet. Aura AuraConfig AuraExt AuraExtConfig AuraId An Aura authority identifier using S/R 25519 as its crypto. Authorship Balance Balance of an account. Balances BalancesConfig Block Block type as expected by this runtime. BlockId BlockId type as expected by this runtime. BlockNumber An index to a block. CollatorSelection CollatorSelectionConfig CollatorSelectionUpdateOrigin We allow root and the StakingAdmin to execute privileged collator selection operations. CumulusXcm Executive Executive: handles dispatch to the various modules. Hash A hash of some data used by the chain. Header Block header type as expected by this runtime. MessageQueue Nonce Index of a transaction in the chain. ParachainInfo ParachainInfoConfig ParachainSystem ParachainSystemConfig PolkadotXcm PolkadotXcmConfig Session SessionConfig SessionHandlers SignedBlock A Block signed with a Justification Sudo SudoConfig System SystemConfig Timestamp TransactionPayment TransactionPaymentConfig TxExtension The TransactionExtension to the basic transaction logic. UncheckedExtrinsic Unchecked extrinsic type as expected by this runtime. Utility VerifySignature WeightReclaim WeightToFeeCoefficients A list of coefficients that represent a polynomial. XcmpQueue derive_impl This attribute can be used to derive a full implementation of a trait based on a local partial
impl and an external impl containing defaults that can be overridden in the local impl.